Documentation
¶
Index ¶
- type Client
- type GetIbcustEntityInfoOK
- type GetIbcustEntityInfoOKBodyItems0
- type GetIbcustEntityInfoOKBodyItems0EntitiesItems0
- type GetIbcustEntityInfoOKBodyItems0EntitiesItems0Address
- type GetIbcustEntityInfoOKBodyItems0EntitiesItems0IdentDocsItems0
- func (o *GetIbcustEntityInfoOKBodyItems0EntitiesItems0IdentDocsItems0) MarshalBinary() ([]byte, error)
- func (o *GetIbcustEntityInfoOKBodyItems0EntitiesItems0IdentDocsItems0) UnmarshalBinary(b []byte) error
- func (o *GetIbcustEntityInfoOKBodyItems0EntitiesItems0IdentDocsItems0) Validate(formats strfmt.Registry) error
- type GetIbcustEntityInfoOKBodyItems0EntitiesItems0Name
- type GetIbcustEntityInfoParams
- func NewGetIbcustEntityInfoParams() *GetIbcustEntityInfoParams
- func NewGetIbcustEntityInfoParamsWithContext(ctx context.Context) *GetIbcustEntityInfoParams
- func NewGetIbcustEntityInfoParamsWithHTTPClient(client *http.Client) *GetIbcustEntityInfoParams
- func NewGetIbcustEntityInfoParamsWithTimeout(timeout time.Duration) *GetIbcustEntityInfoParams
- func (o *GetIbcustEntityInfoParams) SetContext(ctx context.Context)
- func (o *GetIbcustEntityInfoParams) SetHTTPClient(client *http.Client)
- func (o *GetIbcustEntityInfoParams) SetTimeout(timeout time.Duration)
- func (o *GetIbcustEntityInfoParams) WithContext(ctx context.Context) *GetIbcustEntityInfoParams
- func (o *GetIbcustEntityInfoParams) WithHTTPClient(client *http.Client) *GetIbcustEntityInfoParams
- func (o *GetIbcustEntityInfoParams) WithTimeout(timeout time.Duration) *GetIbcustEntityInfoParams
- func (o *GetIbcustEntityInfoParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
- type GetIbcustEntityInfoReader
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client for i b cust API
func New ¶
func New(transport runtime.ClientTransport, formats strfmt.Registry) *Client
New creates a new i b cust API client.
func (*Client) GetIbcustEntityInfo ¶
func (a *Client) GetIbcustEntityInfo(params *GetIbcustEntityInfoParams) (*GetIbcustEntityInfoOK, error)
GetIbcustEntityInfo is b cust entity info
Returns Applicant Id with all owner related entities
func (*Client) SetTransport ¶
func (a *Client) SetTransport(transport runtime.ClientTransport)
SetTransport changes the transport on the client
type GetIbcustEntityInfoOK ¶
type GetIbcustEntityInfoOK struct {
Payload []*GetIbcustEntityInfoOKBodyItems0
}
GetIbcustEntityInfoOK handles this case with default header values.
Search result
func NewGetIbcustEntityInfoOK ¶
func NewGetIbcustEntityInfoOK() *GetIbcustEntityInfoOK
NewGetIbcustEntityInfoOK creates a GetIbcustEntityInfoOK with default headers values
func (*GetIbcustEntityInfoOK) Error ¶
func (o *GetIbcustEntityInfoOK) Error() string
func (*GetIbcustEntityInfoOK) GetPayload ¶
func (o *GetIbcustEntityInfoOK) GetPayload() []*GetIbcustEntityInfoOKBodyItems0
type GetIbcustEntityInfoOKBodyItems0 ¶
type GetIbcustEntityInfoOKBodyItems0 struct {
// applicant Id
ApplicantID float64 `json:"applicantId,omitempty"`
// entities
Entities []*GetIbcustEntityInfoOKBodyItems0EntitiesItems0 `json:"entities"`
}
GetIbcustEntityInfoOKBodyItems0 get ibcust entity info o k body items0 swagger:model GetIbcustEntityInfoOKBodyItems0
func (*GetIbcustEntityInfoOKBodyItems0) MarshalBinary ¶
func (o *GetIbcustEntityInfoOKBodyItems0) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*GetIbcustEntityInfoOKBodyItems0) UnmarshalBinary ¶
func (o *GetIbcustEntityInfoOKBodyItems0) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type GetIbcustEntityInfoOKBodyItems0EntitiesItems0 ¶
type GetIbcustEntityInfoOKBodyItems0EntitiesItems0 struct {
// address
Address *GetIbcustEntityInfoOKBodyItems0EntitiesItems0Address `json:"address,omitempty"`
// can sign
CanSign bool `json:"canSign,omitempty"`
// can trade
CanTrade bool `json:"canTrade,omitempty"`
// ident docs
IdentDocs [][]*GetIbcustEntityInfoOKBodyItems0EntitiesItems0IdentDocsItems0 `json:"identDocs"`
// name
Name *GetIbcustEntityInfoOKBodyItems0EntitiesItems0Name `json:"name,omitempty"`
// type
Type string `json:"type,omitempty"`
}
GetIbcustEntityInfoOKBodyItems0EntitiesItems0 get ibcust entity info o k body items0 entities items0 swagger:model GetIbcustEntityInfoOKBodyItems0EntitiesItems0
func (*GetIbcustEntityInfoOKBodyItems0EntitiesItems0) MarshalBinary ¶
func (o *GetIbcustEntityInfoOKBodyItems0EntitiesItems0) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*GetIbcustEntityInfoOKBodyItems0EntitiesItems0) UnmarshalBinary ¶
func (o *GetIbcustEntityInfoOKBodyItems0EntitiesItems0) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type GetIbcustEntityInfoOKBodyItems0EntitiesItems0Address ¶
type GetIbcustEntityInfoOKBodyItems0EntitiesItems0Address struct {
// city
City string `json:"city,omitempty"`
// compact
Compact string `json:"compact,omitempty"`
// country
Country string `json:"country,omitempty"`
// country code
CountryCode string `json:"countryCode,omitempty"`
// postal code
PostalCode string `json:"postalCode,omitempty"`
// state
State string `json:"state,omitempty"`
// street
Street string `json:"street,omitempty"`
// street2
Street2 string `json:"street2,omitempty"`
}
GetIbcustEntityInfoOKBodyItems0EntitiesItems0Address get ibcust entity info o k body items0 entities items0 address swagger:model GetIbcustEntityInfoOKBodyItems0EntitiesItems0Address
func (*GetIbcustEntityInfoOKBodyItems0EntitiesItems0Address) MarshalBinary ¶
func (o *GetIbcustEntityInfoOKBodyItems0EntitiesItems0Address) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*GetIbcustEntityInfoOKBodyItems0EntitiesItems0Address) UnmarshalBinary ¶
func (o *GetIbcustEntityInfoOKBodyItems0EntitiesItems0Address) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type GetIbcustEntityInfoOKBodyItems0EntitiesItems0IdentDocsItems0 ¶
type GetIbcustEntityInfoOKBodyItems0EntitiesItems0IdentDocsItems0 struct {
// country
Country string `json:"country,omitempty"`
// state
State string `json:"state,omitempty"`
// type
Type string `json:"type,omitempty"`
// value
Value string `json:"value,omitempty"`
}
GetIbcustEntityInfoOKBodyItems0EntitiesItems0IdentDocsItems0 get ibcust entity info o k body items0 entities items0 ident docs items0 swagger:model GetIbcustEntityInfoOKBodyItems0EntitiesItems0IdentDocsItems0
func (*GetIbcustEntityInfoOKBodyItems0EntitiesItems0IdentDocsItems0) MarshalBinary ¶
func (o *GetIbcustEntityInfoOKBodyItems0EntitiesItems0IdentDocsItems0) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*GetIbcustEntityInfoOKBodyItems0EntitiesItems0IdentDocsItems0) UnmarshalBinary ¶
func (o *GetIbcustEntityInfoOKBodyItems0EntitiesItems0IdentDocsItems0) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type GetIbcustEntityInfoOKBodyItems0EntitiesItems0Name ¶
type GetIbcustEntityInfoOKBodyItems0EntitiesItems0Name struct {
// first name
FirstName string `json:"firstName,omitempty"`
// last name
LastName string `json:"lastName,omitempty"`
// salutation
Salutation string `json:"salutation,omitempty"`
}
GetIbcustEntityInfoOKBodyItems0EntitiesItems0Name get ibcust entity info o k body items0 entities items0 name swagger:model GetIbcustEntityInfoOKBodyItems0EntitiesItems0Name
func (*GetIbcustEntityInfoOKBodyItems0EntitiesItems0Name) MarshalBinary ¶
func (o *GetIbcustEntityInfoOKBodyItems0EntitiesItems0Name) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*GetIbcustEntityInfoOKBodyItems0EntitiesItems0Name) UnmarshalBinary ¶
func (o *GetIbcustEntityInfoOKBodyItems0EntitiesItems0Name) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type GetIbcustEntityInfoParams ¶
type GetIbcustEntityInfoParams struct {
Context context.Context
HTTPClient *http.Client
// contains filtered or unexported fields
}
GetIbcustEntityInfoParams contains all the parameters to send to the API endpoint for the get ibcust entity info operation typically these are written to a http.Request
func NewGetIbcustEntityInfoParams ¶
func NewGetIbcustEntityInfoParams() *GetIbcustEntityInfoParams
NewGetIbcustEntityInfoParams creates a new GetIbcustEntityInfoParams object with the default values initialized.
func NewGetIbcustEntityInfoParamsWithContext ¶
func NewGetIbcustEntityInfoParamsWithContext(ctx context.Context) *GetIbcustEntityInfoParams
NewGetIbcustEntityInfoParamsWithContext creates a new GetIbcustEntityInfoParams object with the default values initialized, and the ability to set a context for a request
func NewGetIbcustEntityInfoParamsWithHTTPClient ¶
func NewGetIbcustEntityInfoParamsWithHTTPClient(client *http.Client) *GetIbcustEntityInfoParams
NewGetIbcustEntityInfoParamsWithHTTPClient creates a new GetIbcustEntityInfoParams object with the default values initialized, and the ability to set a custom HTTPClient for a request
func NewGetIbcustEntityInfoParamsWithTimeout ¶
func NewGetIbcustEntityInfoParamsWithTimeout(timeout time.Duration) *GetIbcustEntityInfoParams
NewGetIbcustEntityInfoParamsWithTimeout creates a new GetIbcustEntityInfoParams object with the default values initialized, and the ability to set a timeout on a request
func (*GetIbcustEntityInfoParams) SetContext ¶
func (o *GetIbcustEntityInfoParams) SetContext(ctx context.Context)
SetContext adds the context to the get ibcust entity info params
func (*GetIbcustEntityInfoParams) SetHTTPClient ¶
func (o *GetIbcustEntityInfoParams) SetHTTPClient(client *http.Client)
SetHTTPClient adds the HTTPClient to the get ibcust entity info params
func (*GetIbcustEntityInfoParams) SetTimeout ¶
func (o *GetIbcustEntityInfoParams) SetTimeout(timeout time.Duration)
SetTimeout adds the timeout to the get ibcust entity info params
func (*GetIbcustEntityInfoParams) WithContext ¶
func (o *GetIbcustEntityInfoParams) WithContext(ctx context.Context) *GetIbcustEntityInfoParams
WithContext adds the context to the get ibcust entity info params
func (*GetIbcustEntityInfoParams) WithHTTPClient ¶
func (o *GetIbcustEntityInfoParams) WithHTTPClient(client *http.Client) *GetIbcustEntityInfoParams
WithHTTPClient adds the HTTPClient to the get ibcust entity info params
func (*GetIbcustEntityInfoParams) WithTimeout ¶
func (o *GetIbcustEntityInfoParams) WithTimeout(timeout time.Duration) *GetIbcustEntityInfoParams
WithTimeout adds the timeout to the get ibcust entity info params
func (*GetIbcustEntityInfoParams) WriteToRequest ¶
func (o *GetIbcustEntityInfoParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type GetIbcustEntityInfoReader ¶
type GetIbcustEntityInfoReader struct {
// contains filtered or unexported fields
}
GetIbcustEntityInfoReader is a Reader for the GetIbcustEntityInfo structure.
func (*GetIbcustEntityInfoReader) ReadResponse ¶
func (o *GetIbcustEntityInfoReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)
ReadResponse reads a server response into the received o.